@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Originally based on rhythmbox/lib/rb-debug.c
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -21,6 +22,8 @@
  */
 
 #include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
@@ -28,15 +31,16 @@
 #include <time.h>
 #include <syslog.h>
 
+#include "gpm-common.h"
 #include "gpm-debug.h"
 #include "gpm-common.h"
 
 static gboolean is_init = FALSE;	/* if we are initialised */
 static gboolean do_verbose = FALSE;	/* if we should print out debugging */
-static gboolean done_warning = FALSE;	/* if we've done the bugzilla warning */
-
-/* Based on rhythmbox/lib/rb-debug.c */
 
+/**
+ * gpm_print_line:
+ **/
 static void
 gpm_print_line (const char *func,
 		const char *file,
@@ -55,6 +59,9 @@ gpm_print_line (const char *func,
 	g_free (str_time);
 }
 
+/**
+ * gpm_debug_real:
+ **/
 void
 gpm_debug_real (const char *func,
 		const char *file,
@@ -75,6 +82,9 @@ gpm_debug_real (const char *func,
 	gpm_print_line (func, file, line, buffer);
 }
 
+/**
+ * gpm_warning_real:
+ **/
 void
 gpm_warning_real (const char *func,
 		  const char *file,
@@ -95,15 +105,28 @@ gpm_warning_real (const char *func,
 	/* do extra stuff for a warning */
 	fprintf (stderr, "*** WARNING ***\n");
 	gpm_print_line (func, file, line, buffer);
-	if (! done_warning) {
-		fprintf (stderr, "%s has encountered a non-critical warning.\n"
-			 "Consult %s for any known issues or a possible fix.\n"
-			 "Please file a bug with this complete message if not present\n",
-			 "GNOME Power Manager", GPM_BUGZILLA_URL);
-		done_warning = TRUE;
-	}
 }
 
+/**
+ * gpm_bugzilla:
+ *
+ * Asks the user to consult and add to bugzilla.
+ **/
+void
+gpm_bugzilla (void)
+{
+	fprintf (stderr, "%s has encountered a non-critical warning.\n"
+		 "Consult %s for any known issues or a possible fix.\n"
+		 "Please file a bug with this complete message if not present\n",
+		 "GNOME Power Manager", GPM_BUGZILLA_URL);
+}
+
+/**
+ * gpm_syslog:
+ * @format: This va format string, e.g. ("test %s", hello)
+ *
+ * Logs some text to the syslog, usually in /var/log/messages
+ **/
 void
 gpm_syslog (const char *format, ...)
 {
@@ -115,9 +138,13 @@ gpm_syslog (const char *format, ...)
 	va_end (args);
 
 	gpm_debug ("Saving to syslog: %s", buffer);
-	syslog (LOG_ALERT, "%s", buffer);
+	syslog (LOG_NOTICE, "(%s) %s", g_get_user_name (), buffer);
 }
 
+/**
+ * gpm_debug_init:
+ * @debug: If we should print out verbose logging
+ **/
 void
 gpm_debug_init (gboolean debug)
 {
@@ -125,6 +152,7 @@ gpm_debug_init (gboolean debug)
 	if (is_init) {
 		return;
 	}
+	is_init = TRUE;
 
 	do_verbose = debug;
 	gpm_debug ("Verbose debugging %s", (do_verbose) ? "enabled" : "disabled");
@@ -133,6 +161,45 @@ gpm_debug_init (gboolean debug)
 	openlog ("gnome-power-manager", LOG_NDELAY, LOG_USER);
 }
 
+/**
+ * gpm_critical_error:
+ * @content: The content to show, e.g. "No icons detected"
+ *
+ * Shows a gtk critical error and logs to syslog.
+ * NOTE: we will loose memory, but since this program is a critical error
+ * that is the least of our problems...
+ **/
+void
+gpm_critical_error (const char *format, ...)
+{
+	va_list args;
+	char    buffer [1025];
+	GtkWidget *dialog;
+
+	va_start (args, format);
+	g_vsnprintf (buffer, 1024, format, args);
+	va_end (args);
+
+	gpm_syslog ("Critical error: %s", buffer);
+	dialog = gtk_message_dialog_new_with_markup (NULL,
+						     GTK_DIALOG_MODAL,
+						     GTK_MESSAGE_WARNING,
+						     GTK_BUTTONS_OK,
+						     "<span size='larger'><b>%s</b></span>",
+						     GPM_NAME);
+	gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
+						    buffer);
+	/* we close the gtk loop when the user clicks ok */
+	g_signal_connect_swapped (dialog,
+				  "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  dialog);
+	gtk_widget_show (dialog);
+}
+
+/**
+ * gpm_debug_shutdown:
+ **/
 void
 gpm_debug_shutdown (void)
 {
