@@ -166,10 +166,10 @@ main (int argc, char *argv[])
 	if (error) {
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_critical_error ("This program cannot start until you start the dbus "
-				    "<i>system</i> service.\n"
-				    "It is <b>strongly recommended</b> you reboot your compter "
-				    "after starting messagebus.");
+		gpm_critical_error ("This program cannot start until you start "
+				    "the dbus system service.\n"
+				    "It is <b>strongly recommended</b> you reboot "
+				    "your computer after starting this service.");
 		/* abort at this point */
 		exit (1);
 	}
@@ -179,7 +179,7 @@ main (int argc, char *argv[])
 		gpm_warning ("%s", error->message);
 		g_error_free (error);
 		gpm_critical_error ("This program cannot start until you start the "
-				    "dbus <i>session</i> service.\n\n"
+				    "dbus session service.\n\n"
 				    "This is usually started automatically in X "
 				    "or gnome startup when you start a new session.");
 		/* abort at this point */
