@@ -103,6 +103,7 @@ struct GpmManagerPrivate
 
 	GpmDpms		*dpms;
 	GpmIdle		*idle;
+	GpmHal		*hal;
 	GpmInfo		*info;
 	GpmFeedback	*feedback;
 	GpmPower	*power;
@@ -207,6 +208,19 @@ gpm_manager_is_policy_timout_valid (GpmManager *manager,
 	return TRUE;
 }
 
+/**
+ * gpm_manager_reset_event_time:
+ * @manager: This manager class instance
+ *
+ * Resets the time so we do not do any more actions until the
+ * timeout has passed.
+ **/
+static void
+gpm_manager_reset_event_time (GpmManager *manager)
+{
+	manager->priv->last_resume_event = time (NULL);
+}
+
 /**
  * gpm_manager_is_inhibit_valid:
  * @manager: This manager class instance
@@ -227,12 +241,13 @@ gpm_manager_is_inhibit_valid (GpmManager *manager,
 
 	action_ok = gpm_inhibit_check (manager->priv->inhibit);
 	if (! action_ok) {
+		GString *message = g_string_new ("");
+
 		if (manager->priv->ignore_inhibits) {
 			gpm_debug ("Inhibit ignored through gconf policy!");
 			return TRUE;
 		}
 		title = g_strdup_printf (_("Request to %s"), action);
-		GString *message = g_string_new ("");
 		gpm_inhibit_get_message (manager->priv->inhibit, message, action);
 		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
 				      title,
@@ -270,7 +285,7 @@ gpm_manager_allowed_suspend (GpmManager *manager,
 	*can = FALSE;
 	gconf_ok = gconf_client_get_bool (manager->priv->gconf_client,
 					      GPM_PREF_CAN_SUSPEND, NULL);
-	hal_ok = gpm_hal_can_suspend ();
+	hal_ok = gpm_hal_can_suspend (manager->priv->hal);
 #ifdef HAVE_POLKIT
 	polkit_ok = gpm_polkit_is_user_privileged (manager->priv->polkit, "hal-power-suspend");
 #endif
@@ -302,7 +317,7 @@ gpm_manager_allowed_hibernate (GpmManager *manager,
 	*can = FALSE;
 	gconf_ok = gconf_client_get_bool (manager->priv->gconf_client,
 					      GPM_PREF_CAN_HIBERNATE, NULL);
-	hal_ok = gpm_hal_can_hibernate ();
+	hal_ok = gpm_hal_can_hibernate (manager->priv->hal);
 #ifdef HAVE_POLKIT
 	polkit_ok = gpm_polkit_is_user_privileged (manager->priv->polkit, "hal-power-hibernate");
 #endif
@@ -324,8 +339,9 @@ gpm_manager_allowed_shutdown (GpmManager *manager,
 			      gboolean   *can,
 			      GError    **error)
 {
-	*can = FALSE;
 	gboolean polkit_ok = TRUE;
+	g_return_val_if_fail (can, FALSE);
+	*can = FALSE;
 #ifdef HAVE_POLKIT
 	polkit_ok = gpm_polkit_is_user_privileged (manager->priv->polkit, "hal-power-shutdown");
 #endif
@@ -347,8 +363,9 @@ gpm_manager_allowed_reboot (GpmManager *manager,
 			    gboolean   *can,
 			    GError    **error)
 {
-	*can = FALSE;
 	gboolean polkit_ok = TRUE;
+	g_return_val_if_fail (can, FALSE);
+	*can = FALSE;
 #ifdef HAVE_POLKIT
 	polkit_ok = gpm_polkit_is_user_privileged (manager->priv->polkit, "hal-power-reboot");
 #endif
@@ -530,39 +547,94 @@ sync_dpms_policy (GpmManager *manager)
 	GError  *error;
 	gboolean res;
 	gboolean on_ac;
+	guint    timeout;
 	guint    standby;
 	guint    suspend;
 	guint    off;
+	char    *dpms_method;
 
 	error = NULL;
 
 	gpm_power_get_on_ac (manager->priv->power, &on_ac, NULL);
 
 	if (on_ac) {
-		standby = gconf_client_get_int (manager->priv->gconf_client,
+		error = NULL;
+		timeout = gconf_client_get_int (manager->priv->gconf_client,
 						GPM_PREF_AC_SLEEP_DISPLAY,
 						&error);
+		if (error) {
+			gpm_warning ("Unable to get DPMS timeout: %s", error->message);
+			g_error_free (error);
+		}
+
+		error = NULL;
+		dpms_method = gconf_client_get_string (manager->priv->gconf_client,
+						       GPM_PREF_AC_DPMS_METHOD,
+						       &error);
+		if (error) {
+			gpm_warning ("Unable to get DPMS suspend method: %s", error->message);
+			g_error_free (error);
+		}
 	} else {
-		standby = gconf_client_get_int (manager->priv->gconf_client,
+		error = NULL;
+		timeout = gconf_client_get_int (manager->priv->gconf_client,
 						GPM_PREF_BATTERY_SLEEP_DISPLAY,
 						&error);
-	}
+		if (error) {
+			gpm_warning ("Unable to get DPMS timeout: %s", error->message);
+			g_error_free (error);
+		}
 
-	if (error) {
-		gpm_warning ("Unable to get DPMS timeouts: %s", error->message);
-		g_error_free (error);
-		return;
+		error = NULL;
+		dpms_method = gconf_client_get_string (manager->priv->gconf_client,
+						       GPM_PREF_BATTERY_DPMS_METHOD,
+						       &error);
+		if (error) {
+			gpm_warning ("Unable to get DPMS suspend method: %s", error->message);
+			g_error_free (error);
+		}
 	}
 
 	/* old policy was in seconds, warn the user if too small */
-	if (standby < 60) {
+	if (timeout < 60) {
 		gpm_warning ("standby timeout is invalid, please re-configure");
 		return;
 	}
 
-	/* try to make up some reasonable numbers */
-	suspend = standby;
-	off     = standby * 2;
+	/* If we have no dpms_method, possible due to a schema problem */
+	if (dpms_method == NULL) {
+		g_warning ("DPMS method unknown. Possible schema problem!");
+		return;
+	}
+
+	/* Some monitors do not support certain suspend states, so we have to
+	 * provide a way to only use the one that works. */
+	if (strcmp (dpms_method, "default") == 0) {
+		/* suspend after one timeout, turn off after another */
+		standby = timeout;
+		suspend = timeout;
+		off     = timeout * 2;
+	} else if (strcmp (dpms_method, "standby") == 0) {
+		standby = timeout;
+		suspend = 0;
+		off     = 0;
+	} else if (strcmp (dpms_method, "suspend") == 0) {
+		standby = 0;
+		suspend = timeout;
+		off     = 0;
+	} else if (strcmp (dpms_method, "off") == 0) {
+		standby = 0;
+		suspend = 0;
+		off     = timeout;
+	} else {
+		/* wtf? */
+		g_warning ("unknown dpms mode!");
+		g_free (dpms_method);
+		return;
+	}
+
+	gpm_debug ("DPMS parameters %d %d %d, method '%s'\n", standby, suspend, off, dpms_method);
+	g_free (dpms_method);
 
 	error = NULL;
 	res = gpm_dpms_set_enabled (manager->priv->dpms, TRUE, &error);
@@ -663,10 +735,12 @@ change_power_policy (GpmManager *manager,
 		power_save = gconf_client_get_bool (client, GPM_PREF_BATTERY_LOWPOWER, NULL);
 	}
 
-	gpm_brightness_set_level_std (manager->priv->brightness, brightness);
-	gpm_brightness_set (manager->priv->brightness);
+	if (gpm_brightness_has_hardware (manager->priv->brightness)) {
+		gpm_brightness_set_level_std (manager->priv->brightness, brightness);
+		gpm_brightness_set (manager->priv->brightness);
+	}
 
-	gpm_hal_enable_power_save (power_save);
+	gpm_hal_enable_power_save (manager->priv->hal, power_save);
 	update_ac_throttle (manager, on_ac);
 
 	/* set the new sleep (inactivity) value */
@@ -725,6 +799,7 @@ gpm_manager_blank_screen (GpmManager *manager,
 {
 	gboolean do_lock;
 	gboolean ret = TRUE;
+	GError  *error = NULL;
 
 	gpm_info_event_log (manager->priv->info, GPM_GRAPH_EVENT_DPMS_OFF, NULL);
 
@@ -734,7 +809,6 @@ gpm_manager_blank_screen (GpmManager *manager,
 		if (!gpm_screensaver_lock (manager->priv->screensaver))
 			gpm_debug ("Could not lock screen via gnome-screensaver");
 	}
-	GError     *error = NULL;
 	gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_OFF, &error);
 	if (error) {
 		gpm_debug ("Unable to set DPMS mode: %s", error->message);
@@ -898,14 +972,15 @@ gpm_manager_get_low_power_mode (GpmManager  *manager,
 				gboolean    *retval,
 				GError     **error)
 {
+	gboolean on_ac;
+	gboolean power_save;
+
 	g_return_val_if_fail (GPM_IS_MANAGER (manager), FALSE);
 
 	if (retval == NULL) {
 		return FALSE;
 	}
 
-	gboolean on_ac;
-	gboolean power_save;
 	gpm_power_get_on_ac (manager->priv->power, &on_ac, error);
 	if (on_ac) {
 		power_save = gconf_client_get_bool (manager->priv->gconf_client,
@@ -1040,7 +1115,7 @@ gpm_manager_shutdown (GpmManager *manager,
 				   GNOME_SAVE_GLOBAL,
 				   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 
-	gpm_hal_shutdown ();
+	gpm_hal_shutdown (manager->priv->hal);
 	ret = TRUE;
 
 	return ret;
@@ -1073,7 +1148,7 @@ gpm_manager_reboot (GpmManager *manager,
 				   GNOME_SAVE_GLOBAL,
 				   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
 
-	gpm_hal_reboot ();
+	gpm_hal_reboot (manager->priv->hal);
 	ret = TRUE;
 
 	return ret;
@@ -1116,7 +1191,7 @@ gpm_manager_hibernate (GpmManager *manager,
 
 	gpm_networkmanager_sleep ();
 
-	ret = gpm_hal_hibernate ();
+	ret = gpm_hal_hibernate (manager->priv->hal);
 	manager_explain_reason (manager, GPM_GRAPH_EVENT_RESUME,
 				_("Resuming computer"), NULL);
 
@@ -1130,10 +1205,10 @@ gpm_manager_hibernate (GpmManager *manager,
 		show_notify = gconf_client_get_bool (manager->priv->gconf_client,
 						     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
 		if (show_notify) {
+			const char *title = _("Hibernate Problem");
 			message = g_strdup_printf (_("HAL failed to %s. "
 						     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
 						     _("hibernate"), GPM_FAQ_URL);
-			const char *title = _("Hibernate Problem");
 			gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
 					      title,
 					      message,
@@ -1154,7 +1229,7 @@ gpm_manager_hibernate (GpmManager *manager,
 	sync_dpms_policy (manager);
 
 	/* save the time that we resumed */
-	manager->priv->last_resume_event = time (NULL);
+	gpm_manager_reset_event_time (manager);
 
 	return ret;
 }
@@ -1176,8 +1251,11 @@ gpm_manager_suspend (GpmManager *manager,
 	gboolean allowed;
 	gboolean ret;
 	gboolean do_lock;
+	gboolean show_notify;
 	GpmPowerStatus status;
 	char *message;
+	int charge_before_suspend;
+	int charge_difference;
 
 	gpm_manager_allowed_suspend (manager, &allowed, NULL);
 
@@ -1203,10 +1281,10 @@ gpm_manager_suspend (GpmManager *manager,
 	gpm_power_get_battery_status (manager->priv->power,
 				      GPM_POWER_KIND_PRIMARY,
 				      &status);
-	int charge_before_suspend = status.current_charge;
+	charge_before_suspend = status.current_charge;
 
 	/* Do the suspend */
-	ret = gpm_hal_suspend (0);
+	ret = gpm_hal_suspend (manager->priv->hal, 0);
 	manager_explain_reason (manager, GPM_GRAPH_EVENT_RESUME,
 				_("Resuming computer"), NULL);
 
@@ -1217,7 +1295,7 @@ gpm_manager_suspend (GpmManager *manager,
 	gpm_power_get_battery_status (manager->priv->power,
 				      GPM_POWER_KIND_PRIMARY,
 				      &status);
-	int charge_difference = status.current_charge - charge_before_suspend;
+	charge_difference = status.current_charge - charge_before_suspend;
 	if (charge_difference != 0) {
 		if (charge_difference > 0) {
 			message = g_strdup_printf (_("Battery charged %imWh during suspend"),
@@ -1232,7 +1310,6 @@ gpm_manager_suspend (GpmManager *manager,
 		g_free (message);
 	}
 
-	gboolean show_notify;
 	/* We only show the HAL failed notification if set in gconf */
 	show_notify = gconf_client_get_bool (manager->priv->gconf_client,
 					     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
@@ -1262,7 +1339,7 @@ gpm_manager_suspend (GpmManager *manager,
 	sync_dpms_policy (manager);
 
 	/* save the time that we resumed */
-	manager->priv->last_resume_event = time (NULL);
+	gpm_manager_reset_event_time (manager);
 
 	return ret;
 }
@@ -1369,7 +1446,7 @@ idle_changed_cb (GpmIdle    *idle,
 		/* Should we resume the screen? */
 		do_laptop_dim = gconf_client_get_bool (manager->priv->gconf_client,
 						       GPM_PREF_IDLE_DIM_SCREEN, NULL);
-		if (do_laptop_dim) {
+		if (do_laptop_dim && gpm_brightness_has_hardware (manager->priv->brightness)) {
 			/* resume to the previous brightness */
 			manager_explain_reason (manager, GPM_GRAPH_EVENT_SCREEN_RESUME,
 						_("Screen resume"),
@@ -1395,7 +1472,7 @@ idle_changed_cb (GpmIdle    *idle,
 		/* Should we dim the screen? */
 		do_laptop_dim = gconf_client_get_bool (manager->priv->gconf_client,
 						       GPM_PREF_IDLE_DIM_SCREEN, NULL);
-		if (do_laptop_dim) {
+		if (do_laptop_dim && gpm_brightness_has_hardware (manager->priv->brightness)) {
 			/* Dim the screen, fixes #328564 */
 			manager_explain_reason (manager, GPM_GRAPH_EVENT_SCREEN_DIM,
 						_("Screen dim"),
@@ -1677,11 +1754,17 @@ power_on_ac_changed_cb (GpmPower   *power,
 			gboolean    on_ac,
 			GpmManager *manager)
 {
+	gboolean event_when_closed;
+
 	gpm_debug ("Setting on-ac: %d", on_ac);
 
 	/* simulate user input, to fix #333525 */
 	gpm_screensaver_poke (manager->priv->screensaver);
 
+	/* Don't do any events for a few seconds after we remove the
+	 * ac_adapter. See #348201 for details */
+	gpm_manager_reset_event_time (manager);
+
 	/* If we are on AC power we should show warnings again */
 	if (on_ac) {
 		gpm_debug ("Resetting warning to NONE as on AC power");
@@ -1711,7 +1794,6 @@ power_on_ac_changed_cb (GpmPower   *power,
 
 	/* We do the lid close on battery action if the ac_adapter is removed
 	   when the laptop is closed and on battery. Fixes #331655 */
-	gboolean event_when_closed;
 	event_when_closed = gconf_client_get_bool (manager->priv->gconf_client,
 						   GPM_PREF_BATT_EVENT_WHEN_CLOSED, NULL);
 	if (event_when_closed && (!on_ac) && manager->priv->lid_is_closed) {
@@ -1894,7 +1976,8 @@ battery_status_changed_primary (GpmManager     *manager,
 	/* We only re-enable the fully charged notification when the battery
 	   drops down to 95% as some batteries charge to 100% and then fluctuate
 	   from ~98% to 100%. See #338281 for details */
-	if (battery_status->percentage_charge < 95) {
+	if (battery_status->percentage_charge < 95 &&
+	    gpm_power_battery_is_charged (battery_status) == FALSE) {
 		manager->priv->done_notify_fully_charged = FALSE;
 	}
 
@@ -2329,6 +2412,14 @@ gconf_key_changed_cb (GConfClient *client,
 
 		sync_dpms_policy (manager);
 
+	} else if (strcmp (entry->key, GPM_PREF_AC_DPMS_METHOD) == 0) {
+
+		sync_dpms_policy (manager);
+
+	} else if (strcmp (entry->key, GPM_PREF_BATTERY_DPMS_METHOD) == 0) {
+
+		sync_dpms_policy (manager);
+
 	} else if (strcmp (entry->key, GPM_PREF_AC_BRIGHTNESS) == 0) {
 
 		if (on_ac) {
@@ -2484,6 +2575,7 @@ tray_icon_destroyed (GtkObject *object, gpointer user_data)
 /**
  * screensaver_auth_request_cb:
  * @manager: This manager class instance
+ * @auth: If we are trying to authenticate
  *
  * Undim the screen when the login screen appears (see #333290)
  **/
@@ -2492,11 +2584,24 @@ screensaver_auth_request_cb (GpmScreensaver *screensaver,
 			     gboolean        auth,
 			     GpmManager     *manager)
 {
+	GError *error;
+
 	/* TODO: This may be a bid of a bodge, as we will have multiple
 		 resume requests -- maybe this need a logic cleanup */
 	if (auth) {
-		gpm_debug ("resuming due to auth begin");
-		gpm_brightness_undim (manager->priv->brightness);
+		if (gpm_brightness_has_hardware (manager->priv->brightness)) {
+			gpm_debug ("undimming lcd due to auth begin");
+			gpm_brightness_undim (manager->priv->brightness);
+		}
+
+		/* We turn on the monitor unconditionally, as we may be using
+		 * a smartcard to authenticate and DPMS might still be on.
+		 * See #350291 for more details */
+		gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
+		if (error) {
+			gpm_warning ("Failed to turn on DPMS: %s", error->message);
+			g_error_free (error);
+		}
 	}
 }
 
@@ -2523,6 +2628,33 @@ screensaver_connection_changed_cb (GpmScreensaver *screensaver,
 	}
 }
 
+/**
+ * hal_daemon_monitor_cb:
+ * @hal: The HAL class instance
+ **/
+static void
+hal_daemon_monitor_cb (GpmHal     *hal,
+		     GpmManager *manager)
+{
+	tray_icon_update (manager);
+}
+
+/**
+ * manager_rescan_buttons:
+ * @manager: This manager class instance
+ *
+ * Rescan the buttons to avoid #346082
+ *
+ * Return value: TRUE, as we want to repeat this action on resume.
+ **/
+static gboolean
+manager_rescan_buttons (GpmManager *manager)
+{
+	g_debug ("rescanning buttons");
+	gpm_hal_device_rescan_capability (manager->priv->hal, "button");
+	return TRUE;
+}
+
 /**
  * gpm_manager_init:
  * @manager: This manager class instance
@@ -2535,6 +2667,7 @@ gpm_manager_init (GpmManager *manager)
 	gboolean check_type_cpu;
 	gboolean enabled;
 	gboolean allowed_in_menu;
+	int lcd_dim_brightness;
 
 	manager->priv = GPM_MANAGER_GET_PRIVATE (manager);
 
@@ -2548,6 +2681,13 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->power, "battery-status-changed",
 			  G_CALLBACK (power_battery_status_changed_cb), manager);
 
+	manager->priv->hal = gpm_hal_new ();
+	g_signal_connect (manager->priv->hal, "daemon-start",
+			  G_CALLBACK (hal_daemon_monitor_cb), manager);
+	g_signal_connect (manager->priv->hal, "daemon-stop",
+			  G_CALLBACK (hal_daemon_monitor_cb), manager);
+	
+
 	manager->priv->screensaver = gpm_screensaver_new ();
 	g_signal_connect (manager->priv->screensaver, "connection-changed",
 			  G_CALLBACK (screensaver_connection_changed_cb), manager);
@@ -2677,7 +2817,7 @@ gpm_manager_init (GpmManager *manager)
 		   manager->priv->suppress_policy_timeout);
 
 	/* Pretend we just resumed when we start to let actions settle */
-	manager->priv->last_resume_event = time (NULL);
+	gpm_manager_reset_event_time (manager);
 
 	/* get percentage policy */
 	manager->priv->low_percentage = gconf_client_get_int (manager->priv->gconf_client,
@@ -2706,10 +2846,12 @@ gpm_manager_init (GpmManager *manager)
 							   GPM_PREF_ACTION_TIME, NULL);
 
 	/* Get dim settings */
-	int lcd_dim_brightness;
-	lcd_dim_brightness = gconf_client_get_int (manager->priv->gconf_client,
-						   GPM_PREF_PANEL_DIM_BRIGHTNESS, NULL);
-	gpm_brightness_set_level_dim (manager->priv->brightness, lcd_dim_brightness);
+	if (gpm_brightness_has_hardware (manager->priv->brightness)) {
+		lcd_dim_brightness = gconf_client_get_int (manager->priv->gconf_client,
+							   GPM_PREF_PANEL_DIM_BRIGHTNESS, NULL);
+		gpm_debug ("lcd_dim_brightness is %i", lcd_dim_brightness);
+		gpm_brightness_set_level_dim (manager->priv->brightness, lcd_dim_brightness);
+	}
 
 	/* Do we beep? */
 	manager->priv->enable_beeping = gconf_client_get_bool (manager->priv->gconf_client,
@@ -2718,6 +2860,9 @@ gpm_manager_init (GpmManager *manager)
 	/* Do we ignore inhibit requests? */
 	manager->priv->ignore_inhibits = gconf_client_get_bool (manager->priv->gconf_client,
 								GPM_PREF_IGNORE_INHIBITS, NULL);
+
+	/* poll the lid periodically to avoid #346082 */
+	g_timeout_add (1000 * 60, (GSourceFunc) manager_rescan_buttons, manager);
 }
 
 /**
@@ -2739,6 +2884,7 @@ gpm_manager_finalize (GObject *object)
 	g_return_if_fail (manager->priv != NULL);
 
 	g_object_unref (manager->priv->gconf_client);
+	g_object_unref (manager->priv->hal);
 	g_object_unref (manager->priv->dpms);
 	g_object_unref (manager->priv->idle);
 	g_object_unref (manager->priv->info);
