@@ -237,11 +237,54 @@ gpm_marshal_VOID__STRING_STRING_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:INT (gpm-marshal.list:6) */
+/* NONE:STRING,STRING,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:6) */
+void
+gpm_marshal_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
+                                                         GValue       *return_value,
+                                                         guint         n_param_values,
+                                                         const GValue *param_values,
+                                                         gpointer      invocation_hint,
+                                                         gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN) (gpointer     data1,
+                                                                            gpointer     arg_1,
+                                                                            gpointer     arg_2,
+                                                                            gboolean     arg_3,
+                                                                            gboolean     arg_4,
+                                                                            gboolean     arg_5,
+                                                                            gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
 
-/* NONE:STRING (gpm-marshal.list:7) */
+  g_return_if_fail (n_param_values == 6);
 
-/* NONE:INT,LONG,BOOLEAN,BOOLEAN (gpm-marshal.list:8) */
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_boolean (param_values + 3),
+            g_marshal_value_peek_boolean (param_values + 4),
+            g_marshal_value_peek_boolean (param_values + 5),
+            data2);
+}
+
+/* NONE:INT (gpm-marshal.list:7) */
+
+/* NONE:STRING (gpm-marshal.list:8) */
+
+/* NONE:INT,LONG,BOOLEAN,BOOLEAN (gpm-marshal.list:9) */
 void
 gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
